==> cheesetracker_0.5.1.orig.tar.gz: cheesetracker-0.5.1/trackercore/typedefs.h <==
/***************************************************************************
                          typedefs.h  -  description
                             -------------------
    begin                : Sat Jan 20 2001
    copyright            : (C) 2001 by c0del4rvi4
    email                : reduz@anime.com.ar
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TYPEDEFS_H
#define TYPEDEFS_H

#include <string>

typedef unsigned char byte;

/******************************
 typedefs.h
 --------

some global definitions
********************************/

#define APP_TITLE "CheeseTracker"
#define APP_VERSION VERSION
#define APP_AUTHOR "(C) 2001,2002 Juan Linietsky"





#define FUNCTION_SUCCESS 0
#define FUNCTION_FAILED -1

#define ERROR(reason) cout << "Error: " << reason << endl
#define BOUND(bvar,bmin,bmax) (bvar>bmax)?bmax:(bvar<bmin)?bmin:bvar

#define NUM_2_THIRD_CHAR(num) ('0'+((num)/100) % 10)
#define NUM_2_SECOND_CHAR(num) ('0'+((num)/10) % 10)
#define NUM_2_FIRST_CHAR(num) ('0'+(num) % 10)
#define BITBOOL(m_exp) ((m_exp)?1:0)

#define OCTAVE 12

// folowing code is from SDL datatype definitions

typedef unsigned char   Uint8;
typedef signed char     Sint8;
typedef unsigned short  Uint16;
typedef signed short    Sint16;
typedef unsigned int    Uint32;
typedef signed int      Sint32;

/* Figure out how to support 64-bit datatypes */
#if defined(__GNUC__) || defined(__MWERKS__) /* MJS */
#define SDL_HAS_64BIT_TYPE      long long
#elif defined(_MSC_VER) /* VC++ */
#define SDL_HAS_64BIT_TYPE      __int64
#endif

/* The 64-bit datatype isn't supported on all platforms */
#ifdef SDL_HAS_64BIT_TYPE
typedef unsigned SDL_HAS_64BIT_TYPE Uint64;
typedef SDL_HAS_64BIT_TYPE Sint64;
#else
/* This is really just a hack to prevent the compiler from complaining */
typedef struct {
        Uint32 hi;
        Uint32 lo;
} Uint64, Sint64;
#endif

#endif /* typedefs.h */

==> cheesetracker_0.9.1.orig.tar.gz: cheesetracker-0.9.1/trackercore/typedefs.h <==
/***************************************************************************
    This file is part of the CheeseTronic Music Tools
    url                  : http://reduz.com.ar/cheesetronic
    copyright            : (C) 2003 by Juan Linietsky
    email                : coding@reduz.com.ar
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/***************************************************************************
                          typedefs.h  -  description
                             -------------------
    begin                : Sat Jan 20 2001
    copyright            : (C) 2001 by c0del4rvi4
    email                : reduz@anime.com.ar
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TYPEDEFS_H
#define TYPEDEFS_H

#include <string>
#include <iostream>

typedef unsigned char byte;

/******************************
 typedefs.h
 --------

some global definitions
********************************/

#define APP_TITLE "CheeseTracker"
#define APP_VERSION VERSION
#define APP_AUTHOR "(C) 2001,2002 Juan Linietsky"





#define FUNCTION_SUCCESS 0
#define FUNCTION_FAILED -1
#define ERROR(reason) do { \
	std::cout << "Error: "<< __FILE__ <<':'<< __LINE__ << ": " << reason << std::endl;\
} while (0)

#define BOUND(bvar,bmin,bmax) (bvar>bmax)?bmax:(bvar<bmin)?bmin:bvar

#define NUM_2_THIRD_CHAR(num) ('0'+((num)/100) % 10)
#define NUM_2_SECOND_CHAR(num) ('0'+((num)/10) % 10)
#define NUM_2_FIRST_CHAR(num) ('0'+(num) % 10)
#define BITBOOL(m_exp) ((m_exp)?1:0)

#define OCTAVE 12

// folowing code is from SDL datatype definitions

typedef unsigned char   Uint8;
typedef signed char     Sint8;
typedef unsigned short  Uint16;
typedef signed short    Sint16;
typedef unsigned int    Uint32;
typedef signed int      Sint32;

using std::string;
/* Figure out how to support 64-bit datatypes */
#if defined(__GNUC__) || defined(__MWERKS__) /* MJS */
#define SDL_HAS_64BIT_TYPE      long long
#elif defined(_MSC_VER) /* VC++ */
#define SDL_HAS_64BIT_TYPE      __int64
#endif

/* The 64-bit datatype isn't supported on all platforms */
#ifdef SDL_HAS_64BIT_TYPE
typedef unsigned SDL_HAS_64BIT_TYPE Uint64;
typedef SDL_HAS_64BIT_TYPE Sint64;
#else
/* This is really just a hack to prevent the compiler from complaining */
typedef struct {
        Uint32 hi;
        Uint32 lo;
} Uint64, Sint64;
#endif

#endif /* typedefs.h */
